#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const dotenv = require("dotenv");
dotenv.config();
const kontist_client_1 = require("../kontist-client");
const kontist = new kontist_client_1.KontistClient();
const commander_1 = require("commander");
const program = new commander_1.Command();
const FORMAT_JSON = "json";
const FORMAT_QIF = "qif";
program
    .command("list [format] [accountId]")
    .description("format can be json or qif")
    .action((format = FORMAT_JSON, accountId) => __awaiter(this, void 0, void 0, function* () {
    try {
        yield kontist.login(process.env.KONTIST_USER, process.env.KONTIST_PASSWORD);
        accountId = accountId || (yield kontist.getAccounts())[0].id;
        const transactions = yield kontist.getTransactions(accountId);
        switch (format) {
            case FORMAT_JSON: {
                process.stdout.write(JSON.stringify(transactions, null, 4));
                break;
            }
            case FORMAT_QIF: {
                const qif = require("qif-writer");
                const data = transactions.map((row) => ({
                    amount: row.amount / 100,
                    date: new Date(row.date).toLocaleDateString("en-US"),
                    memo: row.purpose,
                    payee: row.name,
                }));
                qif.write(data, { type: "Bank" });
                break;
            }
            default:
                throw new Error("Unknown format " + format);
        }
    }
    catch (error) {
        console.error(error);
    }
}));
program.parse(process.argv);
if (!process.argv.slice(2).length) {
    program.outputHelp();
}
//# sourceMappingURL=cli-transaction.js.map