#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const dotenv = require("dotenv");
dotenv.config();
const kontist_client_1 = require("../kontist-client");
const kontist = new kontist_client_1.KontistClient();
const commander_1 = require("commander");
const program = new commander_1.Command();
program
    .command("list [accountId]")
    .description("list all transfers")
    .action((accountId) => __awaiter(this, void 0, void 0, function* () {
    try {
        yield kontist.login(process.env.KONTIST_USER, process.env.KONTIST_PASSWORD);
        accountId = accountId || (yield kontist.getAccounts())[0].id;
        const transactions = kontist.getTransfers(accountId);
        process.stdout.write(JSON.stringify(transactions, null, 4));
    }
    catch (error) {
        console.error(error);
    }
}));
program
    .command("init <recipient> <iban> <amount> <note> [accountId]")
    .description("initiate a transfer, amount is EUR in cents")
    .action((recipient, iban, amount, note, accountId) => __awaiter(this, void 0, void 0, function* () {
    try {
        yield kontist.login(process.env.KONTIST_USER, process.env.KONTIST_PASSWORD);
        accountId = accountId || (yield kontist.getAccounts())[0].id;
        const result = yield kontist.initiateTransfer(accountId, recipient, iban, +amount, note);
        process.stdout.write(JSON.stringify(result, null, 4));
    }
    catch (error) {
        console.error(error);
    }
}));
program
    .command("confirm <transferId> <token> <recipient> <iban> <amount> <note> [accountId]")
    .description("confirm a transfer, use transferId from init call and token from sms")
    .action((transferId, token, recipient, iban, amount, note, accountId) => __awaiter(this, void 0, void 0, function* () {
    try {
        yield kontist.login(process.env.KONTIST_USER, process.env.KONTIST_PASSWORD);
        accountId = accountId || (yield kontist.getAccounts())[0].id;
        const result = yield kontist.confirmTransfer(accountId, transferId, token, recipient, iban, +amount, note);
        process.stdout.write(JSON.stringify(result, null, 4));
    }
    catch (error) {
        console.error(error);
    }
}));
program.parse(process.argv);
if (!process.argv.slice(2).length) {
    program.outputHelp();
}
//# sourceMappingURL=cli-transfer.js.map