import { Client } from "node-rest-client";
export declare class KontistClient extends Client {
    private token;
    /**
     * Return information for logged in user. (via constructor {user: "", password: ""} parameters)
     */
    getUser(): Promise<any>;
    /**
     * Return list of accounts.
     */
    getAccounts(): Promise<any>;
    /**
     * Return list of transactions.
     * @param {number} accountId
     */
    getTransactions(accountId: number): Promise<any>;
    /**
     * Return list of transfers.
     * @param {number} accountId
     */
    getTransfers(accountId: number): Promise<any>;
    /**
     * Create a new transfer, needs to be confirmed with the ´confirmTransfer` method and a
     * authorizationToken (you will receive via sms).
     * @param {number} accountId
     * @param {string} recipient
     * @param {string} iban
     * @param {number} amount cents
     * @param {string} note
     */
    initiateTransfer(accountId: number, recipient: string, iban: string, amount: number, note: string): Promise<any>;
    /**
     * Confirm a transfer with the same parameters as used in `initiateTransfer` and additionally
     * the id returned by the latter and a token provided usually via sms.
     * @param {number} accountId
     * @param {string} transferId
     * @param {string} authorizationToken
     * @param {string} recipient
     * @param {string} iban
     * @param {number} amount cents
     * @param {string} note
     */
    confirmTransfer(accountId: number, transferId: string, authorizationToken: string, recipient: string, iban: string, amount: number, note: string): Promise<any>;
    /**
     * Return a pdf statement.
     * @param {number} accountId
     */
    getStatement(accountId: number, year: string, month: string): Promise<any>;
    /**
     * Return a promise with a jwt token.
     *
     * @param email
     * @param password
     */
    login(email: string, password: string): Promise<string>;
    /**
     * Helper to create promise with call to an endpoint.
     *
     * @param {string} endpoint
     * @param {string} method = get
     * @param {*} data
     */
    private request(endpoint, method?, data?);
    /**
     * Calls rejecter when response has invalid status, calls resolver(data) if status is valid.
     *
     * @param {*} data
     * @param {*} response
     * @param {*} resolver
     * @param {*} rejecter
     */
    private handleResponse(data, response, resolver, rejecter);
}
